Re: [U-Boot] [PATCH v2] S5PC2XX: Rename S5pc2XX to exynos4

2011-11-25 Thread Kyungmin Park
Hi,

New Cortex-A15 also uses the armv7. So it's better to use the exynos itself.
Just remove the number 4.

Thank you,
Kyungmin Park

On 11/25/11, Chander Kashyap  wrote:
> As per new conventions Samsung SoC's are named as Exynos.
> Cortex-A9 based Soc's are named as exynos4. s5pc2xx is cortex-A9
> based, hence renamed to exynos4. This is done as per kernel
> naming convetions.
>
> Similerly s5pc210 is now exynos4210. Hence S5PC210/s5pc210
> suffix/prefix has been renamed to exynos4210/EXYNOS4210
>
> Signed-off-by: Chander Kashyap 
> ---
> Changes for v2:
>   - Removed renaming of s5p-common to exynos4-common
>   - Renamed s5pc210 prefixes to exynos4210
>
> Rebased on following commit.
> 19cdfd3e84bff108febb127b598ac3f1634c768c
> "Ethernut 5 board support"
>
>  MAINTAINERS|6 +-
>  Makefile   |2 +-
>  arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile   |0
>  arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c|   50 
>  arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c  |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/adc.h   |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/clk.h   |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/clock.h |2 +-
>  .../asm/{arch-s5pc2xx => arch-exynos4}/cpu.h   |   62
> ++--
>  .../asm/{arch-s5pc2xx => arch-exynos4}/gpio.h  |   28 +-
>  .../asm/{arch-s5pc2xx => arch-exynos4}/mmc.h   |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/pwm.h   |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/sromc.h |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h |0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/uart.h  |0
>  board/samsung/origen/lowlevel_init.S   |   26 
>  board/samsung/origen/mem_setup.S   |   12 ++--
>  board/samsung/origen/origen.c  |8 +-
>  board/samsung/origen/origen_setup.h|8 +-
>  board/samsung/smdkv310/lowlevel_init.S |   22 
>  board/samsung/smdkv310/mem_setup.S |8 +-
>  board/samsung/smdkv310/smdkv310.c  |8 +-
>  board/samsung/universal_c210/lowlevel_init.S   |   24 
>  board/samsung/universal_c210/universal.c   |8 +-
>  boards.cfg |6 +-
>  include/configs/origen.h   |6 +-
>  include/configs/s5pc210_universal.h|   10 ++--
>  include/configs/smdkv310.h |6 +-
>  28 files changed, 151 insertions(+), 151 deletions(-)
>  rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile (100%)
>  rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c (80%)
>  rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/adc.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clk.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clock.h (99%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/cpu.h (64%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/gpio.h (83%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/mmc.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/pwm.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sromc.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h
> (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/uart.h (100%)
>
> diff --git a/MAINTAINERS b/MAINTAINERS
> index 37bbb34..d493e4e 100644
> --- a/MAINTAINERS
> +++ b/MAINTAINERS
> @@ -691,12 +691,12 @@ Minkyu Kang 
>
>   SMDKC100ARM ARMV7 (S5PC100 SoC)
>   s5p_goniARM ARMV7 (S5PC110 SoC)
> - s5pc210_universal   ARM ARMV7 (S5PC210 SoC)
> + s5pc210_universal   ARM ARMV7 (EXYNOS4210 SoC)
>
>  Chander Kashyap 
>
> - origen  ARM ARMV7 (S5PC210 SoC)
> - SMDKV310ARM ARMV7 (S5PC210 SoC)
> + origen  ARM ARMV7 (EXYNOS4210 SoC)
> + SMDKV310ARM ARMV7 (EXYNOS4210 SoC)
>
>  Torsten Koschorrek 
>   scb9328 ARM920T (i.MXL)
> diff --git a/Makefile b/Makefile
> index fb658f4..646b105 100644
> --- a/Makefile
> +++ b/Makefile
> @@ -296,7 +296,7 @@ endif
>  ifeq ($(SOC),s5pc1xx)
>  LIBS += $(CPUDIR)/s5p-common/libs5p-common.o
>  endif
> -ifeq ($(SOC),s5pc2xx)
> +ifeq ($(SOC),exynos4)
>  LIBS += $(CPUDIR)/s5p-common/libs5p-common.o
>  endif
>
> diff --git a/arch/arm/cpu/armv7/s5pc2xx/Makefile
> b/arch/arm/cpu/armv7/exynos4/Makefile
> similarity index 100%
> rename from arch/arm/cpu/armv7/s5pc2xx/Makefile
> rename to arch/arm/cpu/armv7/exynos4/Makefile
> diff --git a/arch/arm/cpu/armv7/s5pc2xx/clock.c
> b/arch/arm/cpu/armv7/exynos4/clock.c
> similarity index 80%
> rename from arch/arm/cpu/armv7/s5p

[U-Boot] [PATCH v2] S5PC2XX: Rename S5pc2XX to exynos4

2011-11-24 Thread Chander Kashyap
As per new conventions Samsung SoC's are named as Exynos.
Cortex-A9 based Soc's are named as exynos4. s5pc2xx is cortex-A9
based, hence renamed to exynos4. This is done as per kernel
naming convetions.

Similerly s5pc210 is now exynos4210. Hence S5PC210/s5pc210
suffix/prefix has been renamed to exynos4210/EXYNOS4210

Signed-off-by: Chander Kashyap 
---
Changes for v2:
- Removed renaming of s5p-common to exynos4-common
- Renamed s5pc210 prefixes to exynos4210

Rebased on following commit.
19cdfd3e84bff108febb127b598ac3f1634c768c
"Ethernut 5 board support"

 MAINTAINERS|6 +-
 Makefile   |2 +-
 arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile   |0
 arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c|   50 
 arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c  |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/adc.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/clk.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/clock.h |2 +-
 .../asm/{arch-s5pc2xx => arch-exynos4}/cpu.h   |   62 ++--
 .../asm/{arch-s5pc2xx => arch-exynos4}/gpio.h  |   28 +-
 .../asm/{arch-s5pc2xx => arch-exynos4}/mmc.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/pwm.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/sromc.h |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/uart.h  |0
 board/samsung/origen/lowlevel_init.S   |   26 
 board/samsung/origen/mem_setup.S   |   12 ++--
 board/samsung/origen/origen.c  |8 +-
 board/samsung/origen/origen_setup.h|8 +-
 board/samsung/smdkv310/lowlevel_init.S |   22 
 board/samsung/smdkv310/mem_setup.S |8 +-
 board/samsung/smdkv310/smdkv310.c  |8 +-
 board/samsung/universal_c210/lowlevel_init.S   |   24 
 board/samsung/universal_c210/universal.c   |8 +-
 boards.cfg |6 +-
 include/configs/origen.h   |6 +-
 include/configs/s5pc210_universal.h|   10 ++--
 include/configs/smdkv310.h |6 +-
 28 files changed, 151 insertions(+), 151 deletions(-)
 rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile (100%)
 rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c (80%)
 rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/adc.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clk.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clock.h (99%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/cpu.h (64%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/gpio.h (83%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/mmc.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/pwm.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sromc.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/uart.h (100%)

diff --git a/MAINTAINERS b/MAINTAINERS
index 37bbb34..d493e4e 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -691,12 +691,12 @@ Minkyu Kang 
 
SMDKC100ARM ARMV7 (S5PC100 SoC)
s5p_goniARM ARMV7 (S5PC110 SoC)
-   s5pc210_universal   ARM ARMV7 (S5PC210 SoC)
+   s5pc210_universal   ARM ARMV7 (EXYNOS4210 SoC)
 
 Chander Kashyap 
 
-   origen  ARM ARMV7 (S5PC210 SoC)
-   SMDKV310ARM ARMV7 (S5PC210 SoC)
+   origen  ARM ARMV7 (EXYNOS4210 SoC)
+   SMDKV310ARM ARMV7 (EXYNOS4210 SoC)
 
 Torsten Koschorrek 
scb9328 ARM920T (i.MXL)
diff --git a/Makefile b/Makefile
index fb658f4..646b105 100644
--- a/Makefile
+++ b/Makefile
@@ -296,7 +296,7 @@ endif
 ifeq ($(SOC),s5pc1xx)
 LIBS += $(CPUDIR)/s5p-common/libs5p-common.o
 endif
-ifeq ($(SOC),s5pc2xx)
+ifeq ($(SOC),exynos4)
 LIBS += $(CPUDIR)/s5p-common/libs5p-common.o
 endif
 
diff --git a/arch/arm/cpu/armv7/s5pc2xx/Makefile 
b/arch/arm/cpu/armv7/exynos4/Makefile
similarity index 100%
rename from arch/arm/cpu/armv7/s5pc2xx/Makefile
rename to arch/arm/cpu/armv7/exynos4/Makefile
diff --git a/arch/arm/cpu/armv7/s5pc2xx/clock.c 
b/arch/arm/cpu/armv7/exynos4/clock.c
similarity index 80%
rename from arch/arm/cpu/armv7/s5pc2xx/clock.c
rename to arch/arm/cpu/armv7/exynos4/clock.c
index 5ecd475..668166a 100644
--- a/arch/arm/cpu/armv7/s5pc2xx/clock.c
+++ b/arch/arm/cpu/armv7/exynos4/clock.c
@@ -30,11 +30,11 @@
 #define CONFIG_SYS_CLK_FREQ_C210   2400
 #endif
 
-/* s5pc210: return pll clock frequency */
-static unsigned long s5pc210_get_pll_clk(int pllre

Re: [U-Boot] [PATCH v2] S5PC2XX: Rename S5pc2XX to exynos4

2011-11-24 Thread Minkyu Kang
Dear Chander Kashyap,

On 24 November 2011 19:48, Chander Kashyap  wrote:
> As per new conventions Samsung SoC's are named as Exynos.
> Cortex-A9 based Soc's are named as exynos4. s5pc2xx is cortex-A9
> based, hence renamed to exynos4. This is done as per kernel
> naming convetions.
>
> Similerly s5pc210 is now exynos4210. Hence S5PC210/s5pc210
> suffix/prefix has been renamed to EXYNOS4210/exynos4210.
>
> Signed-off-by: Chander Kashyap 
> ---
> Changes for v2:
>        - Removed renaming of s5p-common to exynos4-common
>        - Renamed s5pc210 prefixes to exynos4210
>
>  MAINTAINERS                                        |    6 +-
>  Makefile                                           |    2 +-
>  arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile   |    0
>  arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c    |   50 
>  arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c      |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/adc.h       |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/clk.h       |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/clock.h     |    2 +-
>  .../asm/{arch-s5pc2xx => arch-exynos4}/cpu.h       |   62 
> ++--
>  .../asm/{arch-s5pc2xx => arch-exynos4}/gpio.h      |   28 +-
>  .../asm/{arch-s5pc2xx => arch-exynos4}/mmc.h       |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/pwm.h       |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/sromc.h     |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h |    0
>  .../asm/{arch-s5pc2xx => arch-exynos4}/uart.h      |    0
>  board/samsung/origen/lowlevel_init.S               |   26 
>  board/samsung/origen/mem_setup.S                   |   12 ++--
>  board/samsung/origen/origen.c                      |    8 +-
>  board/samsung/origen/origen_setup.h                |    8 +-
>  board/samsung/smdkv310/lowlevel_init.S             |   22 
>  board/samsung/smdkv310/mem_setup.S                 |    8 +-
>  board/samsung/smdkv310/smdkv310.c                  |    8 +-
>  board/samsung/universal_c210/lowlevel_init.S       |   24 
>  board/samsung/universal_c210/universal.c           |    8 +-
>  boards.cfg                                         |    6 +-
>  include/configs/origen.h                           |    6 +-
>  include/configs/s5pc210_universal.h                |   10 ++--
>  include/configs/smdkv310.h                         |    6 +-
>  28 files changed, 151 insertions(+), 151 deletions(-)
>  rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile (100%)
>  rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c (80%)
>  rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/adc.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clk.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clock.h (99%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/cpu.h (64%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/gpio.h (83%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/mmc.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/pwm.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sromc.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h (100%)
>  rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/uart.h (100%)
>

Applying: S5PC2XX: Rename S5pc2XX to exynos4
error: patch failed: boards.cfg:195
error: boards.cfg: patch does not apply
Patch failed at 0001 S5PC2XX: Rename S5pc2XX to exynos4

I couldn't test your patch.
Please remake the patch.

Thanks
Minkyu Kang
-- 
from. prom.
www.promsoft.net
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH v2] S5PC2XX: Rename S5pc2XX to exynos4

2011-11-24 Thread Chander Kashyap
As per new conventions Samsung SoC's are named as Exynos.
Cortex-A9 based Soc's are named as exynos4. s5pc2xx is cortex-A9
based, hence renamed to exynos4. This is done as per kernel
naming convetions.

Similerly s5pc210 is now exynos4210. Hence S5PC210/s5pc210
suffix/prefix has been renamed to EXYNOS4210/exynos4210.

Signed-off-by: Chander Kashyap 
---
Changes for v2:
- Removed renaming of s5p-common to exynos4-common
- Renamed s5pc210 prefixes to exynos4210

 MAINTAINERS|6 +-
 Makefile   |2 +-
 arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile   |0
 arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c|   50 
 arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c  |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/adc.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/clk.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/clock.h |2 +-
 .../asm/{arch-s5pc2xx => arch-exynos4}/cpu.h   |   62 ++--
 .../asm/{arch-s5pc2xx => arch-exynos4}/gpio.h  |   28 +-
 .../asm/{arch-s5pc2xx => arch-exynos4}/mmc.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/pwm.h   |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/sromc.h |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h |0
 .../asm/{arch-s5pc2xx => arch-exynos4}/uart.h  |0
 board/samsung/origen/lowlevel_init.S   |   26 
 board/samsung/origen/mem_setup.S   |   12 ++--
 board/samsung/origen/origen.c  |8 +-
 board/samsung/origen/origen_setup.h|8 +-
 board/samsung/smdkv310/lowlevel_init.S |   22 
 board/samsung/smdkv310/mem_setup.S |8 +-
 board/samsung/smdkv310/smdkv310.c  |8 +-
 board/samsung/universal_c210/lowlevel_init.S   |   24 
 board/samsung/universal_c210/universal.c   |8 +-
 boards.cfg |6 +-
 include/configs/origen.h   |6 +-
 include/configs/s5pc210_universal.h|   10 ++--
 include/configs/smdkv310.h |6 +-
 28 files changed, 151 insertions(+), 151 deletions(-)
 rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/Makefile (100%)
 rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/clock.c (80%)
 rename arch/arm/cpu/armv7/{s5pc2xx => exynos4}/soc.c (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/adc.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clk.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/clock.h (99%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/cpu.h (64%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/gpio.h (83%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/mmc.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/pwm.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sromc.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/sys_proto.h (100%)
 rename arch/arm/include/asm/{arch-s5pc2xx => arch-exynos4}/uart.h (100%)

diff --git a/MAINTAINERS b/MAINTAINERS
index 030fe4a..36f8400 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -690,12 +690,12 @@ Minkyu Kang 
 
SMDKC100ARM ARMV7 (S5PC100 SoC)
s5p_goniARM ARMV7 (S5PC110 SoC)
-   s5pc210_universal   ARM ARMV7 (S5PC210 SoC)
+   s5pc210_universal   ARM ARMV7 (EXYNOS4210 SoC)
 
 Chander Kashyap 
 
-   origen  ARM ARMV7 (S5PC210 SoC)
-   SMDKV310ARM ARMV7 (S5PC210 SoC)
+   origen  ARM ARMV7 (EXYNOS4210 SoC)
+   SMDKV310ARM ARMV7 (EXYNOS4210 SoC)
 
 Torsten Koschorrek 
scb9328 ARM920T (i.MXL)
diff --git a/Makefile b/Makefile
index 294c762..641b644 100644
--- a/Makefile
+++ b/Makefile
@@ -303,7 +303,7 @@ endif
 ifeq ($(SOC),s5pc1xx)
 LIBS += $(CPUDIR)/s5p-common/libs5p-common.o
 endif
-ifeq ($(SOC),s5pc2xx)
+ifeq ($(SOC),exynos4)
 LIBS += $(CPUDIR)/s5p-common/libs5p-common.o
 endif
 
diff --git a/arch/arm/cpu/armv7/s5pc2xx/Makefile 
b/arch/arm/cpu/armv7/exynos4/Makefile
similarity index 100%
rename from arch/arm/cpu/armv7/s5pc2xx/Makefile
rename to arch/arm/cpu/armv7/exynos4/Makefile
diff --git a/arch/arm/cpu/armv7/s5pc2xx/clock.c 
b/arch/arm/cpu/armv7/exynos4/clock.c
similarity index 80%
rename from arch/arm/cpu/armv7/s5pc2xx/clock.c
rename to arch/arm/cpu/armv7/exynos4/clock.c
index 5ecd475..668166a 100644
--- a/arch/arm/cpu/armv7/s5pc2xx/clock.c
+++ b/arch/arm/cpu/armv7/exynos4/clock.c
@@ -30,11 +30,11 @@
 #define CONFIG_SYS_CLK_FREQ_C210   2400
 #endif
 
-/* s5pc210: return pll clock frequency */
-static unsigned long s5pc210_get_pll_clk(int pllreg)
+/* exynos4210: return pll clock frequency */
+static unsigned long exynos4210_get_pll_clk(int